@@ -1,11 +1,11 @@
 package Mail::BIMI::VMC::Cert;
 # ABSTRACT: Class to model a VMC Cert
-our $VERSION = '2.20200930.1'; # VERSION
+our $VERSION = '2.20201006.1'; # VERSION
 use 5.20.0;
 use Moose;
 use Mail::BIMI::Prelude;
 use Convert::ASN1;
-use Crypt::OpenSSL::X509;
+use Crypt::OpenSSL::X509 1.813;
 use Crypt::OpenSSL::Verify 0.20;
 use File::Slurp qw{ read_file write_file };
 use File::Temp;
@@ -147,7 +147,7 @@ Mail::BIMI::VMC::Cert - Class to model a VMC Cert
 
 =head1 VERSION
 
-version 2.20200930.1
+version 2.20201006.1
 
 =head1 DESCRIPTION
 
